#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['boa', 'boa.admin', 'boa.cmd', 'boa.templates', 'boa.utils']

package_data = \
{'': ['*'], 'boa': ['plop-templates/*'], 'boa.templates': ['app/*']}

install_requires = \
['werkzeug==0.16.1',
 'flask==1.1.1',
 'click>=8.0.1',
 'flask-admin>=1.5.8',
 'Flask-SQLAlchemy>=2.4.1',
 'Flask-Migrate==2.5.2',
 'flask-babel>=0.12.2',
 'itsdangerous==2.0.1',
 'jinja2==3.0.1',
 'markupsafe==2.0.1',
 'requests>=2.26.0',
 'wtforms==2.3.3',
 'pytz==2021.1',
 'SQLAlchemy>=1.3.11',
 'python-dotenv>=0.18.0',
 'PyMySQL>=0.9.3']

entry_points = \
{'console_scripts': ['boa = boa.cmd:boa_cli', 'bws = boa.cmd:boa_cli']}

setup(name='bws-boa',
      version='0.0.4a0',
      description='Builder Web Services',
      author='Jose Angel Delgado',
      author_email='esojangel@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
