
# from .view import FrontView
# from .view import ApiView

def register_frontend_views(admin):
    '''
        Llamamos esta funcion para registrar en el MAPP NODE 
    '''
    pass
    # admin.register_frontend(FrontView, endpoint="main/frontview/")


def register_api_views(admin):
    '''
        Llamamos esta funcion para registrar solo las urls
    '''
    pass
    # admin.register_api(ApiView, endpoint="main/apiview/")


